==> TuxGuitar-0.2.tar.gz: TuxGuitar-0.2/src/org/herac/tuxguitar/gui/items/menu/NoteEffectsMenuItem.java <==
/*
 * Created on 02-dic-2005
 *
 * TODO To change the template for this generated file go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
package org.herac.tuxguitar.gui.items.menu;

import org.eclipse.swt.SWT;
import org.eclipse.swt.widgets.Menu;
import org.eclipse.swt.widgets.MenuItem;
import org.eclipse.swt.widgets.Shell;
import org.herac.tuxguitar.gui.TablatureEditor;
import org.herac.tuxguitar.gui.TuxGuitar;
import org.herac.tuxguitar.gui.actions.effects.ChangeBendNoteAction;
import org.herac.tuxguitar.gui.actions.effects.ChangeHammerNoteAction;
import org.herac.tuxguitar.gui.actions.effects.ChangeSlideNoteAction;
import org.herac.tuxguitar.gui.actions.effects.ChangeVibratoNoteAction;
import org.herac.tuxguitar.gui.items.ItemContainer;

/**
 * @author julian
 *
 * TODO To change the template for this generated type comment go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
public class NoteEffectsMenuItem implements ItemContainer{
    private TablatureEditor tablatureEditor;
    private MenuItem noteEffectsMenuItem;
    private Menu menu; 
    private MenuItem vibrato;
    private MenuItem bend;
    private MenuItem slide;
    private MenuItem hammer;
    
    public NoteEffectsMenuItem(Shell shell,Menu parent, int style,TablatureEditor tablatureEditor) {
        this.noteEffectsMenuItem = new MenuItem(parent, style);
        this.tablatureEditor = tablatureEditor;
        this.menu = new Menu(shell, SWT.DROP_DOWN);
    }    
    
    public void showItems(){                        
        //--VIBRATO--
        this.vibrato = new MenuItem(this.menu, SWT.PUSH);        
        this.vibrato.setText("Vibrato");            
        this.vibrato.addSelectionListener(TuxGuitar.instance().getAction(ChangeVibratoNoteAction.NAME));

        //--BEND--
        this.bend = new MenuItem(this.menu, SWT.PUSH);        
        this.bend.setText("Bend");            
        this.bend.addSelectionListener(TuxGuitar.instance().getAction(ChangeBendNoteAction.NAME));        

        //--SLIDE--
        this.slide = new MenuItem(this.menu, SWT.PUSH);        
        this.slide.setText("Slide");            
        this.slide.addSelectionListener(TuxGuitar.instance().getAction(ChangeSlideNoteAction.NAME));  

        //--HAMMER--
        this.hammer = new MenuItem(this.menu, SWT.PUSH);        
        this.hammer.setText("Hammer On/Pull Off");            
        this.hammer.addSelectionListener(TuxGuitar.instance().getAction(ChangeHammerNoteAction.NAME));          
        
        this.noteEffectsMenuItem.setText("&Effects");
        this.noteEffectsMenuItem.setMenu(menu);
    }    
    
    public void update(){
        
    }
}

==> TuxGuitar-0.3.tar.gz: TuxGuitar-0.3/src/org/herac/tuxguitar/gui/items/menu/NoteEffectsMenuItem.java <==
/*
 * Created on 02-dic-2005
 *
 * TODO To change the template for this generated file go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
package org.herac.tuxguitar.gui.items.menu;

import org.eclipse.swt.SWT;
import org.eclipse.swt.widgets.Menu;
import org.eclipse.swt.widgets.MenuItem;
import org.eclipse.swt.widgets.Shell;
import org.herac.tuxguitar.gui.TablatureEditor;
import org.herac.tuxguitar.gui.TuxGuitar;
import org.herac.tuxguitar.gui.actions.effects.ChangeBendNoteAction;
import org.herac.tuxguitar.gui.actions.effects.ChangeHammerNoteAction;
import org.herac.tuxguitar.gui.actions.effects.ChangeSlideNoteAction;
import org.herac.tuxguitar.gui.actions.effects.ChangeVibratoNoteAction;
import org.herac.tuxguitar.gui.items.ItemContainer;

/**
 * @author julian
 *
 * TODO To change the template for this generated type comment go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
public class NoteEffectsMenuItem implements ItemContainer{
    private TablatureEditor tablatureEditor;
    private MenuItem noteEffectsMenuItem;
    private Menu menu; 
    private MenuItem vibrato;
    private MenuItem bend;
    private MenuItem slide;
    private MenuItem hammer;
    
    public NoteEffectsMenuItem(Shell shell,Menu parent, int style,TablatureEditor tablatureEditor) {
        this.noteEffectsMenuItem = new MenuItem(parent, style);
        this.tablatureEditor = tablatureEditor;
        this.menu = new Menu(shell, SWT.DROP_DOWN);
    }    
    
    public void showItems(){                        
        //--VIBRATO--
        this.vibrato = new MenuItem(this.menu, SWT.PUSH);        
        this.vibrato.addSelectionListener(TuxGuitar.instance().getAction(ChangeVibratoNoteAction.NAME));

        //--BEND--
        this.bend = new MenuItem(this.menu, SWT.PUSH);        
        this.bend.addSelectionListener(TuxGuitar.instance().getAction(ChangeBendNoteAction.NAME));        

        //--SLIDE--
        this.slide = new MenuItem(this.menu, SWT.PUSH);        
        this.slide.addSelectionListener(TuxGuitar.instance().getAction(ChangeSlideNoteAction.NAME));  

        //--HAMMER--
        this.hammer = new MenuItem(this.menu, SWT.PUSH);                           
        this.hammer.addSelectionListener(TuxGuitar.instance().getAction(ChangeHammerNoteAction.NAME));          
        
        this.noteEffectsMenuItem.setMenu(menu);
        
        this.loadProperties();
    }    
    
    public void update(){
        
    }
    
    public void loadProperties(){
        this.noteEffectsMenuItem.setText(TuxGuitar.getProperty("effects"));        
        this.vibrato.setText(TuxGuitar.getProperty("effects.vibrato"));
        this.bend.setText(TuxGuitar.getProperty("effects.bend"));
        this.slide.setText(TuxGuitar.getProperty("effects.slide"));
        this.hammer.setText(TuxGuitar.getProperty("effects.hammer"));
    }       
}
